@@ -27,6 +27,7 @@ from .const import (
     STATE_CONNECTED,
     STATE_CONNECTING,
     STATE_DISCONNECTED,
+    SubscriptionReconnectionReason,
 )
 from .utils import gather_callbacks
 
@@ -154,7 +155,9 @@ class BaseIoT:
                 break
 
             if self.require_subscription and self.cloud.subscription_expired:
-                self.cloud.async_initialize_subscription_expired_handler()
+                self.cloud.async_initialize_subscription_reconnection_handler(
+                    SubscriptionReconnectionReason.SUBSCRIPTION_EXPIRED,
+                )
                 break
 
             self.state = STATE_CONNECTING
